/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2006 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: LogicalCluster.java 9355 2006-08-03 16:18:39Z durieuxp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.management.cluster;


import javax.management.JMException;
import javax.management.ObjectName;

import org.objectweb.jonas.jmx.JonasObjectName;
import org.objectweb.jonas.management.monitoring.ServerProxy;

import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Logical Cluster: may be created by jonasAdmin, or declared in domain.xml
 * A default logical cluster is created for each domain, it holds all the
 * servers in the doamin.
 * @author Adriana Danes
 * @author Philippe Durieux
 */
public class LogicalCluster extends BaseCluster implements BaseClusterMBean {

    /**
     * The type of Cluster, that is part of the MBean ObjectName
     */
    protected String type = "LogicalCluster";


    /**
     * logical cluster constructor
     * @param cf ClusterFactory
     * @throws JMException could not create MBean instance
     */
    public LogicalCluster(ClusterFactory cf) throws JMException {
        super(cf);
    }

    public ClusterMember createClusterMember(String svname, ServerProxy proxy) {
        return new LogicalClusterMember(svname, proxy);
    }

    // --------------------------------------------------------------------------
    // Other public methods
    // --------------------------------------------------------------------------

    /**
     * @return The String type to be put in the ObjectName
     */
    public String getType() {
        return type;
    }

    /**
     * Add a Server to the list
     * Make link between the member and the ServerProxy.
     * @param serverName name of the managed server
     * @param proxy The ServerProxy related object.
     * @return True if correctly added in the List.
     */
    public boolean addServer(String serverName, ServerProxy proxy) {

        // Create the LogicalClusterMember object
        LogicalClusterMember server = new LogicalClusterMember(serverName, proxy);

        // Add this member if not already there
        boolean added = addMember(server);
        if (added) {
            // Build the ObjectName and register MBean
            ObjectName on = null;
            try {
                on = JonasObjectName.clusterMember(serverName, getType(), name);
                server.setObjectName(on);
                jmx.registerMBean(server, on.toString());
            } catch (JMException e) {
                logger.log(BasicLevel.WARN, "Cannot register " + on + ": " + e);
            }
        }
        return added;
    }

}