/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2006 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TomcatCluster.java 9337 2006-08-03 08:55:03Z durieuxp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.management.cluster;


import javax.management.JMException;
import javax.management.ObjectName;

import org.objectweb.jonas.jmx.JonasObjectName;
import org.objectweb.jonas.management.monitoring.ServerProxy;

import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Implements Tomcat Cluster MBean
 * @author Adriana Danes, Philippe Durieux
 */
public class TomcatCluster extends BaseCluster implements TomcatClusterMBean {

    /**
     * The type of Cluster, that is part of the MBean ObjectName
     */
    protected String type = "TomcatCluster";

    /**
     *
     */
    private String mcastAddr = null;

    /**
     *
     */
    private long mcastDropTime;

    /**
     *
     */
    private long mcastFrequency;

    /**
     *
     */
    private int mcastPort;

    /**
     *
     */
    private int mcastSocketTimeout;

    /**
     * Web level loadbalancing cluster constructor
     * @param cf ClusterFactory
     * @throws JMException could not create MBean instance
     */
    public TomcatCluster(TomcatClusterFactory cf) throws JMException {
        super(cf);
    }

    public ClusterMember createClusterMember(String svname, ServerProxy proxy) {
        return new TomcatClusterMember(svname, proxy);
    }

    // --------------------------------------------------------------------------
    // Other public methods
    // --------------------------------------------------------------------------

    /**
     * @return The String type to be put in the ObjectName
     */
    public String getType() {
        return type;
    }

    /**
     * Add a Tomcat Servber to the list of the TomcatCluster
     * Make link between the member and the ServerProxy.
     * @param serverName name of the managed server which corresponds to a Tomcat session replication cluster memeber
     * @param hostname servername
     * @param proxy The ServerProxy related object.
     * @return True if correctly added in the List.
     */
    public boolean addTomcatServer(String serverName, String hostname, ServerProxy proxy) {

        // create the TomcatClusterMember instance ( = a tomcat server)
        TomcatClusterMember tomcat = new TomcatClusterMember(serverName, proxy);

        // Add this member if not already there
        boolean added = addMember(tomcat);
        if (added) {
            // Build the ObjectName and register MBean
            try {
                ObjectName on = JonasObjectName.clusterMember(serverName, getType(), name);
                tomcat.setObjectName(on);
                jmx.registerMBean(tomcat, on.toString());
            } catch (JMException e) {
                logger.log(BasicLevel.WARN, "Cannot register tomcat " + serverName + ": " + e);
            }
        }
        return added;
    }

    public String getMcastAddr() {
        return mcastAddr;
    }
    public long getMcastDropTime() {
        return mcastDropTime;
    }
    public long getMcastFrequency() {
        return mcastFrequency;
    }
    public int getMcastPort() {
        return mcastPort;
    }
    public int getMcastSocketTimeout() {
        return mcastSocketTimeout;
    }

    public void setMcastAddr(String mcastAddr) {
        this.mcastAddr = mcastAddr;
    }

    public void setMcastDropTime(long mcastDropTime) {
        this.mcastDropTime = mcastDropTime;
    }

    public void setMcastFrequency(long mcastFrequency) {
        this.mcastFrequency = mcastFrequency;
    }

    public void setMcastPort(int mcastPort) {
        this.mcastPort = mcastPort;
    }

    public void setMcastSocketTimeout(int mcastSocketTimeout) {
        this.mcastSocketTimeout = mcastSocketTimeout;
    }
}