/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EditDomainDeployAction.java 9390 2006-08-08 09:10:24 +0000 (Tue, 08 Aug 2006) durieuxp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.deploy;

import java.io.IOException;
import java.util.ArrayList;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.J2eeObjectName;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.webapp.jonasadmin.Jlists;
import org.objectweb.jonas.webapp.jonasadmin.JonasAdminJmx;

/**
 *
 * @author Patrick Smith
 *         Greg Lapouchnian
 *         Adriana Danes
 */

public class EditDomainDeployAction extends BaseDeployAction {

    static final int indentUnit = 2;
    static final char indentChar = '_';
// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
        , HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        // Form used
        DomainDeployForm oForm = (DomainDeployForm) p_Form;
        try {
            // Store type deployment if exists
            setCurrentJonasDeployment(p_Request);
            // Domain ObjectName
            ObjectName on = JonasAdminJmx.getJ2eeDomainObjectName();

            // All targets in the domain: started servers and clusters
            ArrayList alTargets = new ArrayList();
            ArrayList alTargetNames = new ArrayList();
            getTargetServerList(alTargetNames, alTargets, on);
            // Deployable files (All files on the local server)
            ArrayList alDeployable = getListDeployableFiles();

            // Deploy files
            ArrayList alDeploy = new ArrayList(alDeployable);

            // Set in form
            oForm.setListDeployable(alDeployable);
            oForm.setListTargets(alTargets);
            oForm.setListTargetNames(alTargetNames);
            oForm.setListDeploy(alDeploy);
            oForm.setDeploy(Jlists.getString(alDeploy, Jlists.SEPARATOR));
            oForm.setIsConfigurable(isConfigurable());

        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }
        // Forward to the jsp.
        return (p_Mapping.findForward(getForwardEdit()));
    }

    /**
     *
     * @param targetNames List of target names
     * @param targetONs List of target ONs
     * @param domainOn domain ObjectName
     * @return total number of target servers and clusters
     * @throws MalformedObjectNameException
     */
    int getTargetServerList(ArrayList targetNames, ArrayList targetONs, ObjectName domainOn) throws MalformedObjectNameException {
        String domainName = domainOn.getKeyProperty("name");
        String[] startedServers = (String[]) JonasManagementRepr.getAttribute(domainOn, "startedServers");

        for (int i = 0; i < startedServers.length; i++) {
            String serverName = ObjectName.getInstance(startedServers[i]).getKeyProperty("name");
            targetNames.add(serverName);
            targetONs.add(startedServers[i]);
        }

        String[] clusters = (String []) JonasManagementRepr.getAttribute(domainOn, "clusters");
        for (int i = 0; i < clusters.length; i++) {
            ObjectName clOn = ObjectName.getInstance(clusters[i]);
            String clusterName =  clOn.getKeyProperty("name");
            if (!clusterName.equals(domainName)) {
                targetNames.add(clusterName);
                targetONs.add(clusters[i]);
            }
        }

        return startedServers.length + clusters.length;
    }
}
