/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2005 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ApplyJonasServersAction.java 8260 2006-04-20 09:56:43Z danesa $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.domain;

import java.io.IOException;
import java.util.ArrayList;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.webapp.jonasadmin.JonasBaseAction;

/**
 * Implement actions for servers management in a domain/cluster
 * Possible actions are:
 * - move a server from a cluster to the parent or to a child
 * - remove a server from the cluster
 *
 * @author Adriana Danes
 */

public class ApplyJonasServersAction extends JonasBaseAction {

//	--------------------------------------------------------- Public Methods
    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
            , HttpServletRequest p_Request, HttpServletResponse p_Response)
    throws IOException, ServletException {

        // Form used
        ItemsServersForm oForm = (ItemsServersForm) p_Form;
        // Geet action
        String action = oForm.getAction();
        // Get domain
        String domainName = m_WhereAreYou.getCurrentDomainName();
        try {
            // Current J2EEDomain MBean
            ObjectName currentOn = ObjectName.getInstance((String) m_Session.getAttribute("currentOn"));
            // Set current domain/cluster name
            String currentName = getStringAttribute(currentOn, "myName");
            oForm.setCurrent(currentName);
            if ("move".equals(action)) {
                // child clusters
                String[] clusters = (String[]) m_Session.getAttribute("currentClusters");
                String[] proposedClusters = null;
                if (currentOn.getKeyProperty("clusterName") != null) {
                    // This is a cluster
                    String parentClusterName = currentOn.getKeyProperty("parentClusterName");
                    proposedClusters = new String[clusters.length + 1];
                    int i = 0;
                    for (; i < clusters.length;) {
                        proposedClusters[i] = clusters[i];
                        i++;
                    }
                    proposedClusters[i] = parentClusterName;
                } else {
                    proposedClusters = clusters;
                }
                oForm.setClusters(proposedClusters);
                return p_Mapping.findForward("ActionJonasServersMove");
            } else if ("remove".equals(action)) {
                ArrayList alSelected = new ArrayList();
                for (int i = 0; i < oForm.getSelectedItems().length; i++) {
                    String selectedServerOn = oForm.getSelectedItems()[i];
                    ObjectName on = ObjectName.getInstance(selectedServerOn);
                    JonasServerItem item = new JonasServerItem(on);
                    alSelected.add(item);
                }
                m_Session.setAttribute("listServersSelected", alSelected);

                // Forward to the Servers Confirm page
                return p_Mapping.findForward("JonasServersConfirm");
            } else if ("undeploy".equals(action)) {
                return p_Mapping.findForward("ActionUndeployModule");
            } else {
                throw new IllegalStateException("Unknown action. Actions supported on domain are move, remove and undeploy");
            }
        } catch (Throwable t) {
                addGlobalError(t);
                saveErrors(p_Request, m_Errors);
                return (p_Mapping.findForward("Global Error"));
        }
    }
}
