/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2005 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: UndeployModuleAction.java 8260 2006-04-20 09:56:43Z danesa $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.domain;

import java.io.IOException;
import java.util.ArrayList;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.J2eeObjectName;
import org.objectweb.jonas.webapp.jonasadmin.JonasBaseAction;

/**
 * @author Adriana Danes
 */

public class UndeployModuleAction extends JonasBaseAction {

//	--------------------------------------------------------- Public Methods
    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
            , HttpServletRequest p_Request, HttpServletResponse p_Response)
    throws IOException, ServletException {

        // Form used
        ItemsServersForm oForm = (ItemsServersForm) p_Form;

        String currentOn = (String) m_Session.getAttribute("currentOn");
        String domainName = m_WhereAreYou.getCurrentDomainName();
        // Actions
        String action = oForm.getAction();
        if (action.equals("confirm")) {
            try {
                ObjectName on = ObjectName.getInstance(currentOn);
                int nbTargets = oForm.getSelectedItems().length;
                String[] targets = new String[nbTargets];
                for (int i = 0; i < oForm.getSelectedItems().length; i++) {
                    String selecteServerName = oForm.getSelectedItems()[i];
                    ObjectName onServer = J2eeObjectName.J2EEServer(domainName, selecteServerName);
                    targets[i] = onServer.toString();
                }
                String module = oForm.getFirstModule();
                String op = null;
                if (module.endsWith("ear")) {
                    op = "unDeployEar";
                } else if (module.endsWith("jar")) {
                    op = "unDeployJar";
                } else if (module.endsWith("war")) {
                    op = "unDeployWar";
                } else if (module.endsWith("rar")) {
                    op = "unDeployRar";
                }
                if (op != null) {
                    Object[] params = {targets, module };
                    String[] signature = {"[Ljava.lang.String;", "java.lang.String" };
                    JonasManagementRepr.invoke(on, op, params, signature);
                }
            } catch (Throwable t) {
                addGlobalError(t);
                saveErrors(p_Request, m_Errors);
                return (p_Mapping.findForward("Global Error"));
            }
            // Forward to the Servers Confirm page
            return p_Mapping.findForward("ActionEditDomain");

        } else {
            // Undeploy module
            try {
                ObjectName on = ObjectName.getInstance(currentOn);
                ArrayList alSelected = new ArrayList();
                if (oForm.getSelectedItems().length > 0) {
                    String selectedModule = oForm.getSelectedItems()[0];
                    oForm.setFirstModule(selectedModule);
                    String[] params = {selectedModule };
                    String[] signature = {"java.lang.String" };
                    String[] tragets = (String []) JonasManagementRepr.invoke(on, "getDeploymentTargets", params, signature);
                    for (int j = 0; j < tragets.length; j++) {
                        ObjectName onServer = J2eeObjectName.J2EEServer(domainName, tragets[j]);
                        JonasServerItem item = new JonasServerItem(onServer);
                        alSelected.add(item);
                    }
                    m_Session.setAttribute("listServersSelected", alSelected);
                } else {
                    oForm.setFirstModule(null);
                }
            } catch (Throwable t) {
                addGlobalError(t);
                saveErrors(p_Request, m_Errors);
                return (p_Mapping.findForward("Global Error"));
            }

            // Forward to the Servers Confirm page
            return p_Mapping.findForward("UndeployModuleConfirm");
        }
    }
}
